@@ -4,7 +4,7 @@ from django.core.management.base import BaseCommand  # , CommandError
 from django.utils import timezone
 
 from ...utils.filesystem import run_dumpdata_backup, move_dumpdata_backup
-from ...settings import DJANGO_PROJECT_BACKUP_DUMPDATA_JSON_FILENAME, DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER
+from ...settings import DUMPDATA_JSON_FILENAME, BACKUP_DESTINATION_FOLDER
 
 
 class Command(BaseCommand):
@@ -21,8 +21,8 @@ class Command(BaseCommand):
         now = timezone.now().strftime('%Y_%m_%dT%H_%M')
 
         try:
-            dump_all_filepath = os.path.abspath(os.path.join(DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER,
-                                                             DJANGO_PROJECT_BACKUP_DUMPDATA_JSON_FILENAME))
+            dump_all_filepath = os.path.abspath(os.path.join(BACKUP_DESTINATION_FOLDER,
+                                                             DUMPDATA_JSON_FILENAME))
             exit_code = run_dumpdata_backup()
 
             if exit_code != 0:
@@ -34,7 +34,7 @@ class Command(BaseCommand):
                 move_dumpdata_backup(now, compress=options['compress'])
 
                 self.stdout.write(
-                    self.style.SUCCESS('Dumpdata backup moved into "{}"'.format(DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER)))
+                    self.style.SUCCESS('Dumpdata backup moved into "{}"'.format(BACKUP_DESTINATION_FOLDER)))
 
         except Exception as e:
             self.stdout.write(self.style.ERROR('Error executing dumpdata backup: {}'.format(e)))
