@@ -7,7 +7,7 @@ SERIALIZATION_MODULE = 'dpb_couchdb_datastore'
 _EXCLUDED_MODELS = [
     # 'migrations',
     'auth.permission',
-    'contenttypes',
+    'contenttypes.contenttype',
 ]
 EXCLUDED_MODELS = _EXCLUDED_MODELS + getattr(settings, 'DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS', [])
 
